@@ -1,12 +1,14 @@
 #!perl6
 
-use v6.c;
+use v6;
 
+use Panda::Common;
+use Panda::Builder;
 use LibraryMake;
 use Shell::Command;
 
-class Build {
-   	method build($workdir) {
+class Build is Panda::Builder {
+   method build($workdir) {
          my $srcdir = $workdir.IO.child('src').Str;
          my Str $destdir = "$workdir/lib/../resources/libraries";
          mkpath $destdir;
@@ -17,10 +19,6 @@ class Build {
          chdir($srcdir);
          shell(%vars<MAKE>);
          chdir($goback);
-   	}
-    method isa($what) {
-        return True if $what.^name eq 'Panda::Builder';
-        callsame;
-    }
+   }
 }
 # vim: ft=perl6 expandtab sw=4
